# Read cvs list
$dir = "C:\Users\daniel\Documents\Protel\WiringPlan\ISC\D1900511\Project Outputs for D1900511"
$cables = Import-Csv -Path $dir\D1900511_CableList.csv 
# Exluded cables (already long enough)
$excl = ,
# Cable types
$coax="N","TNC","BNC","SMA", "coax"
$dsub="D9M","D9F","D15M","D15F","D25M","D25F","D37M","D37F","M12F","M12M"
$hv="SHV","MIL"
# Find duplicates
echo "Duplicates"
$cables | Sort -Property "Cable Label" |? "Cable Info" -eq "" |
    Group-Object -Property "Cable Label" -NoElement |? Count -gt 1
# Create list
$cables |
    ? {($_."System" -eq "ISC" -and ([Float]$_."Cable Number" -ge 500.0)) -or $_."System" -like "ISC_RF4?-B/"} |
    Sort -Property @{Expression={$_."System"}; Descending=$False},
                   @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {$excl -notcontains $_."Cable Label"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_BHD.csv 
# Create coax list
$cables |
    ? {($_."System" -eq "ISC" -and ([Float]$_."Cable Number" -ge 500.0)) -or $_."System" -like "ISC_RF4?-B/"} |
    Sort -Property @{Expression={$_."System"}; Descending=$False},
                   @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$coax -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_BHD_Coax.csv 
# Create d-sub list
$cables |
    ? {($_."System" -eq "ISC" -and ([Float]$_."Cable Number" -ge 500.0)) -or $_."System" -like "ISC_RF4?-B/"} |
    Sort -Property @{Expression={$_."System"}; Descending=$False},
                   @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$dsub -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_BHD_Dsub.csv 
# Create SHV list
$cables |
    ? {($_."System" -eq "ISC" -and ([Float]$_."Cable Number" -ge 500.0)) -or $_."System" -like "ISC_RF4?-B/"} |
    Sort -Property @{Expression={$_."System"}; Descending=$False},
                   @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$hv -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_BHD_HV.csv 
# Check missed entries
echo ""
echo "Missing"
$cables |
    ? {($_."System" -eq "ISC" -and ([Float]$_."Cable Number" -ge 500.0)) -or $_."System" -like "ISC_RF4?-B/"} |
    Sort -Property @{Expression={$_."System"}; Descending=$False},
                   @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$coax + $dsub + $hv -notcontains $_."From Connector Type"} |
    Group-Object -Property "Cable Label" -NoElement
